@@ -3,7 +3,7 @@ from typing import Any, Iterable
 
 ERROR_CODE = "DOC001"
 CHECK = "missing docstring"
-VERSION = "0.1.4"
+VERSION = "0.1.6"
 
 
 class DocstringChecker(ast.NodeVisitor):
@@ -11,13 +11,22 @@ class DocstringChecker(ast.NodeVisitor):
         super().__init__(*args, **kwargs)
         self.errors: list[tuple[int, int, str]] = []
 
-    def visit_FunctionDef(self, node: ast.FunctionDef) -> None:
+    def function_visitor(self, node: ast.FunctionDef | ast.AsyncFunctionDef) -> None:
         # guard 1: if function is a pytest fixture, don't check for docstring
         if any(
-            isinstance(decorator, ast.Attribute)
-            and decorator.attr == "fixture"
-            and isinstance(decorator.value, ast.Name)
-            and decorator.value.id == "pytest"
+            (
+                isinstance(decorator, ast.Attribute)
+                and decorator.attr == "fixture"
+                and isinstance(decorator.value, ast.Name)
+                and decorator.value.id == "pytest"
+            )
+            or (
+                isinstance(decorator, ast.Call)
+                and isinstance(decorator.func, ast.Attribute)
+                and decorator.func.attr == "fixture"
+                and isinstance(decorator.func.value, ast.Name)
+                and decorator.func.value.id == "pytest"
+            )
             for decorator in node.decorator_list
         ):
             return
@@ -42,6 +51,12 @@ class DocstringChecker(ast.NodeVisitor):
                 )
             )
 
+    def visit_FunctionDef(self, node: ast.FunctionDef) -> None:
+        self.function_visitor(node)
+
+    def visit_AsyncFunctionDef(self, node: ast.AsyncFunctionDef) -> Any:
+        return self.function_visitor(node)
+
 
 class Plugin:
     name = "flake8-has-docstring"
